@@ -45,9 +45,12 @@ cc	CALL FLOPN2(NFL)
 cc	IF (NFL.EQ.0) GO TO 999
 C
 c-------
-      A = 0
-      BR = 0
-      BI = 0
+      A = 0.0D-00
+      BR = 0.0D-00
+      BI = 0.0D-00
+c-------
+      CL = 0.0D-00
+      SL = 0.0D-00
 c-------
 cc	MJ1=51
       CST0 =0.0D-00
